@@ -40,6 +40,9 @@ def help():
         '''
         print(f'''Lista de comandos:
     .ObterTabela() -> extrai os dados de todas as universidades, junta ao banco de daos, trata e possibilita que sejam exbidos na tela de forma correta.
+    .Ordenar(\"dataframe\) -> inicia a classe que contém as funções para organizar a visualização do datframe.
+    \tparâmetro:
+    \t\tnome do dataframe, o objeto ao qual se atribuiu a classe ObterTabela().
     .ruf(\"parametro\") -> Ordena as universidade de acordo com o a RUF 2019, da mais bem colocada para a menos
     \tparâmetros:
     \t\t'Posição em Ensino', 'Posição em Pesquisa',  'Posição em Mercado',  'Posição em Inovação', 
